pub struct Passport {Show 14 fields
pub guid: String,
pub name: String,
pub country: String,
pub passport_number: String,
pub issue_date_month: i64,
pub issue_date_day: i64,
pub issue_date_year: i64,
pub expiry_date_month: i64,
pub expiry_date_day: i64,
pub expiry_date_year: i64,
pub time_created: i64,
pub time_last_used: Option<i64>,
pub time_last_modified: i64,
pub times_used: i64,
}Fields
guid: Stringname: Stringcountry: Stringpassport_number: Stringissue_date_month: i64issue_date_day: i64issue_date_year: i64expiry_date_month: i64expiry_date_day: i64expiry_date_year: i64time_created: i64time_last_used: Option<i64>time_last_modified: i64times_used: i64Trait Implementations
impl<UT> ConvertError<UT> for Passport
impl<UT> ConvertError<UT> for Passport
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
impl<UT> FfiConverter<UT> for Passport
impl<UT> FfiConverter<UT> for Passport
const TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
type FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
fn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
fn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<InternalPassport> for Passport
impl From<InternalPassport> for Passport
Sourcefn from(ip: InternalPassport) -> Self
fn from(ip: InternalPassport) -> Self
Converts to this type from the input type.
impl<UT> LiftReturn<UT> for Passport
impl<UT> LiftReturn<UT> for Passport
type ReturnType = <Passport as Lift<UT>>::FfiType
type ReturnType = <Passport as Lift<UT>>::FfiType
FFI return type for trait interfaces
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
impl<UT> LowerError<UT> for Passport
impl<UT> LowerError<UT> for Passport
fn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
impl<UT> LowerReturn<UT> for Passport
impl<UT> LowerReturn<UT> for Passport
type ReturnType = <Passport as Lower<UT>>::FfiType
type ReturnType = <Passport as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
impl<UT> TypeId<UT> for Passport
impl<UT> TypeId<UT> for Passport
const TYPE_ID_META: MetadataBuffer
impl Eq for Passport
impl StructuralPartialEq for Passport